summaryrefslogtreecommitdiffstats
path: root/twin/clients
diff options
context:
space:
mode:
Diffstat (limited to 'twin/clients')
-rw-r--r--twin/clients/b2/b2client.cpp54
-rw-r--r--twin/clients/b2/b2client.h4
-rw-r--r--twin/clients/default/kdedefault.cpp26
-rw-r--r--twin/clients/keramik/embedtool.cpp4
-rw-r--r--twin/clients/keramik/keramik.cpp56
-rw-r--r--twin/clients/keramik/keramik.h2
-rw-r--r--twin/clients/kwmtheme/cli_installer/main.cpp16
-rw-r--r--twin/clients/kwmtheme/kwmthemeclient.cpp28
-rw-r--r--twin/clients/kwmtheme/kwmthemeclient.h2
-rw-r--r--twin/clients/laptop/laptopclient.cpp24
-rw-r--r--twin/clients/modernsystem/config/config.cpp8
-rw-r--r--twin/clients/modernsystem/config/config.h2
-rw-r--r--twin/clients/modernsystem/modernsys.cpp20
-rw-r--r--twin/clients/plastik/plastik.cpp2
-rw-r--r--twin/clients/plastik/plastikbutton.cpp2
-rw-r--r--twin/clients/plastik/plastikclient.cpp6
-rw-r--r--twin/clients/quartz/quartz.cpp26
-rw-r--r--twin/clients/redmond/redmond.cpp14
-rw-r--r--twin/clients/test/test.cpp2
-rw-r--r--twin/clients/test/test.h2
-rw-r--r--twin/clients/web/Web.cpp32
-rw-r--r--twin/clients/web/Web.h2
-rw-r--r--twin/clients/web/WebButton.cpp26
-rw-r--r--twin/clients/web/WebButton.h4
24 files changed, 182 insertions, 182 deletions
diff --git a/twin/clients/b2/b2client.h b/twin/clients/b2/b2client.h
index 30220b175..d1062348e 100644
--- a/twin/clients/b2/b2client.h
+++ b/twin/clients/b2/b2client.h
@@ -38,7 +38,7 @@ public:
void setToggle(){setToggleType(Toggle);}
void setActive(bool on){setOn(on);}
void setUseMiniIcon(){useMiniIcon = true;}
- TQSize sizeHint() const;
+ TQSize tqsizeHint() const;
TQSizePolicy sizePolicy() const;
protected:
virtual void drawButton(TQPainter *p);
@@ -119,7 +119,7 @@ protected:
Position mousePosition( const TQPoint& p ) const;
void resize(const TQSize&);
void borders(int &, int &, int &, int &) const;
- TQSize minimumSize() const;
+ TQSize tqminimumSize() const;
bool eventFilter(TQObject *, TQEvent *);
private slots:
void menuButtonPressed();
diff --git a/twin/clients/keramik/embedtool.cpp b/twin/clients/keramik/embedtool.cpp
index c73926a1b..d1cbd78fd 100644
--- a/twin/clients/keramik/embedtool.cpp
+++ b/twin/clients/keramik/embedtool.cpp
@@ -20,7 +20,7 @@
*/
#include <tqimage.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqregexp.h>
#include <tqfile.h>
#include <tqfileinfo.h>
@@ -60,7 +60,7 @@ private:
KeramikEmbedder::KeramikEmbedder()
{
- TQDateTime date( TQDateTime::currentDateTime() );
+ TQDateTime date( TQDateTime::tqcurrentDateTime() );
TQString datestring( date.toString() );
file = new TQFile( "tiles.h" );
diff --git a/twin/clients/keramik/keramik.h b/twin/clients/keramik/keramik.h
index 59f9960c5..8e4a98518 100644
--- a/twin/clients/keramik/keramik.h
+++ b/twin/clients/keramik/keramik.h
@@ -148,7 +148,7 @@ namespace Keramik {
virtual Position mousePosition( const TQPoint& p ) const;
virtual void borders( int& left, int& right, int& top, int& bottom ) const;
virtual void resize( const TQSize& s );
- virtual TQSize minimumSize() const;
+ virtual TQSize tqminimumSize() const;
virtual bool eventFilter( TQObject* o, TQEvent* e );
virtual void activeChange();
virtual void captionChange();
diff --git a/twin/clients/kwmtheme/cli_installer/main.cpp b/twin/clients/kwmtheme/cli_installer/main.cpp
index c67a2d227..4533cf3e8 100644
--- a/twin/clients/kwmtheme/cli_installer/main.cpp
+++ b/twin/clients/kwmtheme/cli_installer/main.cpp
@@ -73,36 +73,36 @@ int main(int argc, char **argv)
input.setGroup("Window Border");
output->setGroup("General");
- tmpStr = input.readEntry("shapePixmapTop");
+ tmpStr = input.readEntry("tqshapePixmapTop");
if(!tmpStr.isEmpty()){
copy(srcStr+tmpStr, localDirStr+tmpStr);
}
output->writeEntry("wm_top", tmpStr, true, true);
- tmpStr = input.readEntry("shapePixmapBottom");
+ tmpStr = input.readEntry("tqshapePixmapBottom");
if(!tmpStr.isEmpty())
copy(srcStr+tmpStr, localDirStr+tmpStr);
output->writeEntry("wm_bottom", tmpStr, true, true);
- tmpStr = input.readEntry("shapePixmapLeft");
+ tmpStr = input.readEntry("tqshapePixmapLeft");
if(!tmpStr.isEmpty())
copy(srcStr+tmpStr, localDirStr+tmpStr);
output->writeEntry("wm_left", tmpStr, true, true);
- tmpStr = input.readEntry("shapePixmapRight");
+ tmpStr = input.readEntry("tqshapePixmapRight");
if(!tmpStr.isEmpty())
copy(srcStr+tmpStr, localDirStr+tmpStr);
output->writeEntry("wm_right", tmpStr, true, true);
- tmpStr = input.readEntry("shapePixmapTopLeft");
+ tmpStr = input.readEntry("tqshapePixmapTopLeft");
if(!tmpStr.isEmpty())
copy(srcStr+tmpStr, localDirStr+tmpStr);
output->writeEntry("wm_topleft", tmpStr, true, true);
- tmpStr = input.readEntry("shapePixmapTopRight");
+ tmpStr = input.readEntry("tqshapePixmapTopRight");
if(!tmpStr.isEmpty())
copy(srcStr+tmpStr, localDirStr+tmpStr);
output->writeEntry("wm_topright", tmpStr, true, true);
- tmpStr = input.readEntry("shapePixmapBottomLeft");
+ tmpStr = input.readEntry("tqshapePixmapBottomLeft");
if(!tmpStr.isEmpty())
copy(srcStr+tmpStr, localDirStr+tmpStr);
output->writeEntry("wm_bottomleft", tmpStr, true, true);
- tmpStr = input.readEntry("shapePixmapBottomRight");
+ tmpStr = input.readEntry("tqshapePixmapBottomRight");
if(!tmpStr.isEmpty())
copy(srcStr+tmpStr, localDirStr+tmpStr);
output->writeEntry("wm_bottomright", tmpStr, true, true);
diff --git a/twin/clients/kwmtheme/kwmthemeclient.cpp b/twin/clients/kwmtheme/kwmthemeclient.cpp
index 59b471e25..5d5e462f7 100644
--- a/twin/clients/kwmtheme/kwmthemeclient.cpp
+++ b/twin/clients/kwmtheme/kwmthemeclient.cpp
@@ -1,7 +1,7 @@
#include <kconfig.h>
#include "kwmthemeclient.h"
#include <kglobal.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqdrawutil.h>
#include <tqpainter.h>
#include <kpixmapeffect.h>
@@ -231,7 +231,7 @@ void MyButton::drawButtonLabel(TQPainter *p)
int offset = (isDown() && ((pixmap()->width() >= width()) ||
(pixmap()->height() >= height()))) ? 1 : 0;
style().drawItem(p, TQRect( offset, offset, width(), height() ),
- AlignCenter, colorGroup(),
+ AlignCenter, tqcolorGroup(),
true, pixmap(), TQString::null);
}
}
@@ -364,7 +364,7 @@ void KWMThemeClient::drawTitle(TQPainter &dest)
p.begin(&buffer);
if(titleSunken){
- qDrawShadeRect(&p, r, options()->colorGroup(KDecorationOptions::ColorFrame, isActive()),
+ qDrawShadeRect(&p, r, options()->tqcolorGroup(KDecorationOptions::ColorFrame, isActive()),
true, 1, 0);
r.setRect(r.x()+1, r.y()+1, r.width()-2, r.height()-2);
}
@@ -384,7 +384,7 @@ void KWMThemeClient::drawTitle(TQPainter &dest)
p.drawTiledPixmap(r, *fill);
}
else{
- p.fillRect(r, options()->colorGroup(KDecorationOptions::ColorTitleBar, isActive()).
+ p.fillRect(r, options()->tqcolorGroup(KDecorationOptions::ColorTitleBar, isActive()).
brush(TQColorGroup::Button));
}
p.setFont(options()->font(isActive()));
@@ -402,12 +402,12 @@ void KWMThemeClient::drawTitle(TQPainter &dest)
void KWMThemeClient::resizeEvent( TQResizeEvent* )
{
doShape();
- widget()->repaint();
+ widget()->tqrepaint();
}
void KWMThemeClient::captionChange()
{
- widget()->repaint( titlebar->geometry(), false );
+ widget()->tqrepaint( titlebar->geometry(), false );
}
void KWMThemeClient::paintEvent( TQPaintEvent *)
@@ -557,7 +557,7 @@ void KWMThemeClient::paintEvent( TQPaintEvent *)
}
drawTitle(p);
- TQColor c = widget()->colorGroup().background();
+ TQColor c = widget()->tqcolorGroup().background();
// KWM evidently had a 1 pixel border around the client window. We
// emulate it here, but should be removed at some point in order to
@@ -576,10 +576,10 @@ void KWMThemeClient::paintEvent( TQPaintEvent *)
void KWMThemeClient::doShape()
{
- TQBitmap shapemask(width(), height());
- shapemask.fill(color0);
+ TQBitmap tqshapemask(width(), height());
+ tqshapemask.fill(color0);
TQPainter p;
- p.begin(&shapemask);
+ p.begin(&tqshapemask);
p.setBrush(color1);
p.setPen(color1);
int x,y;
@@ -740,14 +740,14 @@ void KWMThemeClient::doShape()
}
}
p.fillRect(maxExtent-1, maxExtent-1, width()-2*maxExtent+2, height()-2*maxExtent+2, color1);
- setMask(shapemask);
+ setMask(tqshapemask);
}
void KWMThemeClient::showEvent(TQShowEvent *)
{
doShape();
- widget()->repaint(false);
+ widget()->tqrepaint(false);
}
void KWMThemeClient::mouseDoubleClickEvent( TQMouseEvent * e )
@@ -868,9 +868,9 @@ bool KWMThemeClient::eventFilter( TQObject* o, TQEvent* e )
}
}
-TQSize KWMThemeClient::minimumSize() const
+TQSize KWMThemeClient::tqminimumSize() const
{
- return widget()->minimumSize().expandedTo( TQSize( 100, 50 ));
+ return widget()->tqminimumSize().expandedTo( TQSize( 100, 50 ));
}
void KWMThemeClient::resize( const TQSize& s )
diff --git a/twin/clients/kwmtheme/kwmthemeclient.h b/twin/clients/kwmtheme/kwmthemeclient.h
index 58db3d14f..e51bfe6d1 100644
--- a/twin/clients/kwmtheme/kwmthemeclient.h
+++ b/twin/clients/kwmtheme/kwmthemeclient.h
@@ -30,7 +30,7 @@ public:
~KWMThemeClient(){;}
void init();
void resize( const TQSize& s );
- TQSize minimumSize() const;
+ TQSize tqminimumSize() const;
void borders( int& left, int& right, int& top, int& bottom ) const;
protected:
void doShape();
diff --git a/twin/clients/laptop/laptopclient.cpp b/twin/clients/laptop/laptopclient.cpp
index 58d54a118..db37feae6 100644
--- a/twin/clients/laptop/laptopclient.cpp
+++ b/twin/clients/laptop/laptopclient.cpp
@@ -157,7 +157,7 @@ static void create_pixmaps()
KPixmapEffect::VerticalGradient);
}
// buttons (active/inactive, sunken/unsunken, 2 sizes each)
- TQColorGroup g = options()->colorGroup(KDecoration::ColorButtonBg, true);
+ TQColorGroup g = options()->tqcolorGroup(KDecoration::ColorButtonBg, true);
TQColor c = g.background();
btnPix1 = new KPixmap;
btnPix1->resize(btnWidth1, titleHeight);
@@ -184,7 +184,7 @@ static void create_pixmaps()
KPixmapEffect::DiagonalGradient);
KPixmapEffect::gradient(*btnDownPix2, c.dark(130), c.light(120),
KPixmapEffect::DiagonalGradient);
- g = options()->colorGroup(KDecoration::ColorButtonBg, false);
+ g = options()->tqcolorGroup(KDecoration::ColorButtonBg, false);
c = g.background();
KPixmapEffect::gradient(*iBtnPix1, c.light(120), c.dark(130),
KPixmapEffect::DiagonalGradient);
@@ -200,20 +200,20 @@ static void create_pixmaps()
btnDownPix1->fill(c.rgb());
btnPix2->fill(c.rgb());
btnDownPix2->fill(c.rgb());
- g = options()->colorGroup(KDecoration::ColorButtonBg, false);
+ g = options()->tqcolorGroup(KDecoration::ColorButtonBg, false);
c = g.background();
iBtnPix1->fill(c.rgb());
iBtnDownPix1->fill(c.rgb());
iBtnPix2->fill(c.rgb());
iBtnDownPix2->fill(c.rgb());
}
- g = options()->colorGroup(KDecoration::ColorButtonBg, true);
+ g = options()->tqcolorGroup(KDecoration::ColorButtonBg, true);
c = g.background();
drawButtonFrame(btnPix1, g, false);
drawButtonFrame(btnDownPix1, g, true);
drawButtonFrame(btnPix2, g, false);
drawButtonFrame(btnDownPix2, g, true);
- g = options()->colorGroup(KDecoration::ColorButtonBg, false);
+ g = options()->tqcolorGroup(KDecoration::ColorButtonBg, false);
c = g.background();
drawButtonFrame(iBtnPix1, g, false);
drawButtonFrame(iBtnDownPix1, g, true);
@@ -293,7 +293,7 @@ void LaptopButton::setBitmap(const unsigned char *bitmap)
deco.fill(Qt::color0);
}
deco.setMask(deco);
- repaint();
+ tqrepaint();
}
void LaptopButton::drawButton(TQPainter *p)
@@ -314,7 +314,7 @@ void LaptopButton::drawButton(TQPainter *p)
}
}
else{
- TQColorGroup g = options()->colorGroup(KDecoration::ColorButtonBg, decoration()->isActive());
+ TQColorGroup g = options()->tqcolorGroup(KDecoration::ColorButtonBg, decoration()->isActive());
int w = width();
int h = height();
p->fillRect(1, 1, w-2, h-2, isDown() ? g.mid() : g.button());
@@ -469,7 +469,7 @@ void LaptopClient::captionChange()
void LaptopClient::paintEvent( TQPaintEvent* )
{
TQPainter p(widget());
- TQColorGroup g = options()->colorGroup(KDecoration::ColorFrame, isActive());
+ TQColorGroup g = options()->tqcolorGroup(KDecoration::ColorFrame, isActive());
TQRect r(widget()->rect());
p.setPen(Qt::black);
@@ -546,7 +546,7 @@ void LaptopClient::paintEvent( TQPaintEvent* )
p.setFont(options()->font(false, isToolWindow() ));
TQFontMetrics fm(options()->font(false));
- g = options()->colorGroup(KDecoration::ColorTitleBar, false);
+ g = options()->tqcolorGroup(KDecoration::ColorTitleBar, false);
if(iUpperGradient)
p.drawTiledPixmap(r.x()+((r.width()-fm.width(caption()))/2)-4,
r.y(), fm.width(caption())+8, r.height()-1,
@@ -564,7 +564,7 @@ void LaptopClient::paintEvent( TQPaintEvent* )
p.setPen(options()->color(KDecoration::ColorFont, false));
p.drawText(r.x(), r.y(), r.width(), r.height()-1,
AlignCenter, caption() );
- g = options()->colorGroup(KDecoration::ColorFrame, true);
+ g = options()->tqcolorGroup(KDecoration::ColorFrame, true);
p.setPen(g.background());
p.drawPoint(r.x(), r.y());
p.drawPoint(r.right(), r.y());
@@ -629,7 +629,7 @@ void LaptopClient::updateActiveBuffer( )
p.setFont(options()->font(true, isToolWindow() ));
TQFontMetrics fm(options()->font(true));
- TQColorGroup g = options()->colorGroup(KDecoration::ColorTitleBar, true);
+ TQColorGroup g = options()->tqcolorGroup(KDecoration::ColorTitleBar, true);
if(aUpperGradient)
p.drawTiledPixmap(r.x()+((r.width()-fm.width(caption()))/2)-4,
r.y(), fm.width(caption())+8, r.height()-1,
@@ -647,7 +647,7 @@ void LaptopClient::updateActiveBuffer( )
p.setPen(options()->color(KDecoration::ColorFont, true));
p.drawText(r.x(), r.y(), r.width(), r.height()-1,
AlignCenter, caption() );
- g = options()->colorGroup(KDecoration::ColorFrame, true);
+ g = options()->tqcolorGroup(KDecoration::ColorFrame, true);
p.setPen(g.background());
p.drawPoint(r.x(), r.y());
p.drawPoint(r.right(), r.y());
diff --git a/twin/clients/modernsystem/config/config.cpp b/twin/clients/modernsystem/config/config.cpp
index d09d4867d..136ff3492 100644
--- a/twin/clients/modernsystem/config/config.cpp
+++ b/twin/clients/modernsystem/config/config.cpp
@@ -5,7 +5,7 @@
#include <kdialog.h>
#include <klocale.h>
#include <kglobal.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqwhatsthis.h>
#include "config.h"
@@ -59,11 +59,11 @@ ModernSysConfig::ModernSysConfig(KConfig* conf, TQWidget* parent) : TQObject(par
bool rtl = kapp->reverseLayout();
label1 = new TQLabel(i18n("Small"), hbox);
- label1->setAlignment(rtl ? AlignRight : AlignLeft);
+ label1->tqsetAlignment(rtl ? AlignRight : AlignLeft);
label2 = new TQLabel(i18n("Medium"), hbox);
- label2->setAlignment(AlignHCenter);
+ label2->tqsetAlignment(AlignHCenter);
label3 = new TQLabel(i18n("Large"), hbox);
- label3->setAlignment(rtl ? AlignLeft : AlignRight);
+ label3->tqsetAlignment(rtl ? AlignLeft : AlignRight);
vbox->addWidget(handleBox);
vbox->addStretch(1);
diff --git a/twin/clients/modernsystem/config/config.h b/twin/clients/modernsystem/config/config.h
index 3ff794b77..3a04573cf 100644
--- a/twin/clients/modernsystem/config/config.h
+++ b/twin/clients/modernsystem/config/config.h
@@ -3,7 +3,7 @@
#include <tqcheckbox.h>
#include <tqgroupbox.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqvbox.h>
#include <tqslider.h>
#include <tqlabel.h>
diff --git a/twin/clients/modernsystem/modernsys.cpp b/twin/clients/modernsystem/modernsys.cpp
index 9508ab840..b6e7cda01 100644
--- a/twin/clients/modernsystem/modernsys.cpp
+++ b/twin/clients/modernsystem/modernsys.cpp
@@ -4,7 +4,7 @@
#include <kconfig.h>
#include <kglobal.h>
#include <klocale.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqdrawutil.h>
#include <kpixmapeffect.h>
#include <kdrawutil.h>
@@ -171,13 +171,13 @@ static void create_pixmaps()
KPixmapEffect::VerticalGradient);
}
// buttons
- TQColorGroup btnColor(options()->colorGroup(KDecoration::ColorButtonBg, true));
+ TQColorGroup btnColor(options()->tqcolorGroup(KDecoration::ColorButtonBg, true));
buttonPix = new TQPixmap(14, 15);
make_button_fx(btnColor, buttonPix);
buttonPixDown = new TQPixmap(14, 15);
make_button_fx(btnColor, buttonPixDown, true);
- btnColor = options()->colorGroup(KDecoration::ColorButtonBg, false);
+ btnColor = options()->tqcolorGroup(KDecoration::ColorButtonBg, false);
iButtonPix = new TQPixmap(14, 15);
make_button_fx(btnColor, iButtonPix);
iButtonPixDown = new TQPixmap(14, 15);
@@ -515,7 +515,7 @@ void ModernSys::recalcTitleBuffer()
p.drawTiledPixmap(0, 0, width(), title_height+2, *aUpperGradient);
else
p.fillRect(0, 0, width(), title_height+2,
- options()->colorGroup(ColorTitleBar, true).
+ options()->tqcolorGroup(ColorTitleBar, true).
brush(TQColorGroup::Button));
TQRect t = titleRect(); // titlebar->geometry();
@@ -554,7 +554,7 @@ void ModernSys::updateCaption()
void ModernSys::drawRoundFrame(TQPainter &p, int x, int y, int w, int h)
{
kDrawRoundButton(&p, x, y, w, h,
- options()->colorGroup(ColorFrame, isActive()), false);
+ options()->tqcolorGroup(ColorFrame, isActive()), false);
}
@@ -570,9 +570,9 @@ void ModernSys::paintEvent( TQPaintEvent* )
TQPainter p( widget() );
TQRect t = titleRect(); // titlebar->geometry();
- TQBrush fillBrush(widget()->colorGroup().brush(TQColorGroup::Background).pixmap() ?
- widget()->colorGroup().brush(TQColorGroup::Background) :
- options()->colorGroup(ColorFrame, isActive()).
+ TQBrush fillBrush(widget()->tqcolorGroup().tqbrush(TQColorGroup::Background).pixmap() ?
+ widget()->tqcolorGroup().brush(TQColorGroup::Background) :
+ options()->tqcolorGroup(ColorFrame, isActive()).
brush(TQColorGroup::Button));
p.fillRect(1, title_height+3, width()-2, height()-(title_height+3), fillBrush);
@@ -586,7 +586,7 @@ void ModernSys::paintEvent( TQPaintEvent* )
int h = height() - hw;
// titlebar
- TQColorGroup g = options()->colorGroup(ColorTitleBar, isActive());
+ TQColorGroup g = options()->tqcolorGroup(ColorTitleBar, isActive());
if(isActive()){
p.drawPixmap(1, 1, titleBuffer, 0, 0, w-2, title_height+2);
}
@@ -609,7 +609,7 @@ void ModernSys::paintEvent( TQPaintEvent* )
p.drawLine(0, title_height+2, w-2, title_height+2);
// frame
- g = options()->colorGroup(ColorFrame, isActive());
+ g = options()->tqcolorGroup(ColorFrame, isActive());
p.setPen(g.light());
p.drawLine(1, title_height+3, 1, h-2);
p.setPen(g.dark());
diff --git a/twin/clients/plastik/plastik.cpp b/twin/clients/plastik/plastik.cpp
index 76d643904..9faf73df0 100644
--- a/twin/clients/plastik/plastik.cpp
+++ b/twin/clients/plastik/plastik.cpp
@@ -290,7 +290,7 @@ const TQPixmap &PlastikHandler::pixmap(Pixmaps type, bool active, bool toolWindo
} else {
pm = new TQPixmap(1, titleBarTileHeight);
painter.begin(pm);
- painter.drawPixmap(0, 0, gradient, 0,2);
+ painter.tqdrawPixmap(0, 0, gradient, 0,2);
if (m_coloredBorder) {
painter.setPen(getColor(TitleGradient3, active).dark(110) );
} else {
diff --git a/twin/clients/plastik/plastikbutton.cpp b/twin/clients/plastik/plastikbutton.cpp
index 428c8e72c..5f81033cb 100644
--- a/twin/clients/plastik/plastikbutton.cpp
+++ b/twin/clients/plastik/plastikbutton.cpp
@@ -140,7 +140,7 @@ void PlastikButton::animate()
}
}
- repaint(false);
+ tqrepaint(false);
}
void PlastikButton::enterEvent(TQEvent *e)
diff --git a/twin/clients/plastik/plastikclient.cpp b/twin/clients/plastik/plastikclient.cpp
index 591d876ce..0e72ff59c 100644
--- a/twin/clients/plastik/plastikclient.cpp
+++ b/twin/clients/plastik/plastikclient.cpp
@@ -27,7 +27,7 @@
#include <tqfontmetrics.h>
#include <tqimage.h>
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqpainter.h>
#include <tqpixmap.h>
#include <tqdesktopwidget.h>
@@ -435,7 +435,7 @@ void PlastikClient::reset( unsigned long changed )
{
if (changed & SettingColors)
{
- // repaint the whole thing
+ // tqrepaint the whole thing
clearCaptionPixmaps();
widget()->update();
updateButtons();
@@ -445,7 +445,7 @@ void PlastikClient::reset( unsigned long changed )
updateLayout();
- // then repaint
+ // then tqrepaint
clearCaptionPixmaps();
widget()->update();
}
diff --git a/twin/clients/redmond/redmond.cpp b/twin/clients/redmond/redmond.cpp
index 790afa461..9fd625dde 100644
--- a/twin/clients/redmond/redmond.cpp
+++ b/twin/clients/redmond/redmond.cpp
@@ -149,7 +149,7 @@ static void create_pixmaps ()
defaultMenuPix = new TQPixmap(kdelogo);
// buttons (active/inactive, sunken/unsunken)
- TQColorGroup g = options()->colorGroup(KDecoration::ColorButtonBg, true);
+ TQColorGroup g = options()->tqcolorGroup(KDecoration::ColorButtonBg, true);
TQColor c = g.background();
btnPix1->resize(normalTitleHeight, normalTitleHeight-2);
btnDownPix1->resize(normalTitleHeight, normalTitleHeight-2);
@@ -172,7 +172,7 @@ static void create_pixmaps ()
KPixmapEffect::gradient(*miniBtnDownPix1, c.dark(130), c.light(130),
KPixmapEffect::VerticalGradient);
- g = options()->colorGroup(KDecoration::ColorButtonBg, false);
+ g = options()->tqcolorGroup(KDecoration::ColorButtonBg, false);
c = g.background();
KPixmapEffect::gradient(*iBtnPix1, c.light(130), c.dark(130),
KPixmapEffect::VerticalGradient);
@@ -188,7 +188,7 @@ static void create_pixmaps ()
miniBtnPix1->fill(c.rgb());
miniBtnDownPix1->fill(c.rgb());
- g = options()->colorGroup(KDecoration::ColorButtonBg, false);
+ g = options()->tqcolorGroup(KDecoration::ColorButtonBg, false);
c = g.background();
iBtnPix1->fill(c.rgb());
iBtnDownPix1->fill(c.rgb());
@@ -196,13 +196,13 @@ static void create_pixmaps ()
iMiniBtnDownPix1->fill(c.rgb());
}
- g = options()->colorGroup(KDecoration::ColorButtonBg, true);
+ g = options()->tqcolorGroup(KDecoration::ColorButtonBg, true);
drawButtonFrame(btnPix1, g, false);
drawButtonFrame(btnDownPix1, g, true);
drawButtonFrame(miniBtnPix1, g, false);
drawButtonFrame(miniBtnDownPix1, g, true);
- g = options()->colorGroup(KDecoration::ColorButtonBg, false);
+ g = options()->tqcolorGroup(KDecoration::ColorButtonBg, false);
drawButtonFrame(iBtnPix1, g, false);
drawButtonFrame(iBtnDownPix1, g, true);
drawButtonFrame(iMiniBtnPix1, g, false);
@@ -294,7 +294,7 @@ void RedmondButton::setPixmap( const TQPixmap &p )
deco.resize(0, 0);
pix = p;
- repaint(false);
+ tqrepaint(false);
}
@@ -491,7 +491,7 @@ void RedmondDeco::paintEvent( TQPaintEvent* )
// Draw part of the frame that is the frame color
// ==============================================
- TQColorGroup g = options()->colorGroup(KDecoration::ColorFrame, isActive());
+ TQColorGroup g = options()->tqcolorGroup(KDecoration::ColorFrame, isActive());
p.setPen( g.background() );
p.drawLine( x, y, x2-1, y );
p.drawLine( x, y, x, y2-1 );
diff --git a/twin/clients/test/test.cpp b/twin/clients/test/test.cpp
index 2e26a7c41..02fd5b1d3 100644
--- a/twin/clients/test/test.cpp
+++ b/twin/clients/test/test.cpp
@@ -93,7 +93,7 @@ void Decoration::resize( const TQSize& s )
widget()->resize( s );
}
-TQSize Decoration::minimumSize() const
+TQSize Decoration::tqminimumSize() const
{
return TQSize( 100, 50 );
}
diff --git a/twin/clients/test/test.h b/twin/clients/test/test.h
index bfe36fa7c..e1d3d51a6 100644
--- a/twin/clients/test/test.h
+++ b/twin/clients/test/test.h
@@ -22,7 +22,7 @@ class Decoration
virtual MousePosition mousePosition( const TQPoint& p ) const;
virtual void borders( int& left, int& right, int& top, int& bottom ) const;
virtual void resize( const TQSize& s );
- virtual TQSize minimumSize() const;
+ virtual TQSize tqminimumSize() const;
virtual void activeChange() {};
virtual void captionChange() {};
virtual void maximizeChange() {};
diff --git a/twin/clients/web/Web.h b/twin/clients/web/Web.h
index ec1b08dc5..c2c18b0bd 100644
--- a/twin/clients/web/Web.h
+++ b/twin/clients/web/Web.h
@@ -62,7 +62,7 @@ namespace Web
int titleHeight_, borderSize_;
- bool shape_;
+ bool tqshape_;
TQBitmap _buttonBitmap(ButtonType t) const;
};
diff --git a/twin/clients/web/WebButton.cpp b/twin/clients/web/WebButton.cpp
index 785abe699..bf1f54af4 100644
--- a/twin/clients/web/WebButton.cpp
+++ b/twin/clients/web/WebButton.cpp
@@ -69,10 +69,10 @@ namespace Web {
0xff, 0x81, 0x81, 0xff, 0x81, 0xff, 0x81, 0xff
};
-WebButton::WebButton(ButtonType type, WebClient *parent, const char *name, bool shape)
+WebButton::WebButton(ButtonType type, WebClient *parent, const char *name, bool tqshape)
: KCommonDecorationButton (type, parent, name),
mouseOver_ (false),
- shape_ (shape),
+ tqshape_ (tqshape),
deco_ (parent)
{
setBackgroundMode(NoBackground);
@@ -127,7 +127,7 @@ void WebButton::reset(unsigned long changed)
WebButton::enterEvent(TQEvent * e)
{
mouseOver_ = true;
- repaint();
+ tqrepaint();
TQButton::enterEvent(e);
}
@@ -135,7 +135,7 @@ WebButton::enterEvent(TQEvent * e)
WebButton::leaveEvent(TQEvent * e)
{
mouseOver_ = false;
- repaint();
+ tqrepaint();
TQButton::leaveEvent(e);
}
@@ -145,17 +145,17 @@ WebButton::drawButton(TQPainter *p)
TQPen highlightPen;
if (isDown() )
- highlightPen = TQPen(colorGroup().light());
+ highlightPen = TQPen(tqcolorGroup().light());
else
{
if (mouseOver_)
- highlightPen = TQPen(colorGroup().highlight());
+ highlightPen = TQPen(tqcolorGroup().highlight());
else
highlightPen = TQPen(NoPen);
}
- p->fillRect(rect(), colorGroup().background());
+ p->fillRect(rect(), tqcolorGroup().background());
Position position_;
if (0 == mapToParent(rect().topLeft() ).x() )
@@ -174,7 +174,7 @@ WebButton::drawButton(TQPainter *p)
p->drawLine(0, 0, width(), 0);
p->drawLine(0, 1, 0, height() - 1);
- if (shape_)
+ if (tqshape_)
{
p->drawPoint(3, 1);
p->drawPoint(4, 1);
@@ -187,11 +187,11 @@ WebButton::drawButton(TQPainter *p)
p->setBrush(NoBrush);
p->setPen(highlightPen);
- if (shape_)
+ if (tqshape_)
p->setClipRegion(TQRegion(rect()) - TQRect(0, 0, 6, 6));
p->drawRect(2, 2, width() - 4, height() - 4);
- if (shape_)
+ if (tqshape_)
{
p->setClipRect(rect());
p->drawPoint(4, 3);
@@ -210,7 +210,7 @@ WebButton::drawButton(TQPainter *p)
p->setPen(Qt::black);
p->drawLine(0, 0, width(), 0);
p->drawLine(width() - 1, 1, width() - 1, height() - 1);
- if (shape_)
+ if (tqshape_)
{
p->drawPoint(width() - 5, 1);
p->drawPoint(width() - 4, 1);
@@ -223,11 +223,11 @@ WebButton::drawButton(TQPainter *p)
p->setBrush(NoBrush);
p->setPen(highlightPen);
- if (shape_)
+ if (tqshape_)
p->setClipRegion(TQRegion(rect()) - TQRect(width() - 6, 0, 6, 6));
p->drawRect(2, 2, width() - 4, height() - 4);
- if (shape_)
+ if (tqshape_)
{
p->setClipRect(rect());
p->drawPoint(width() - 5, 3);
diff --git a/twin/clients/web/WebButton.h b/twin/clients/web/WebButton.h
index d86db6cc6..108aa2a52 100644
--- a/twin/clients/web/WebButton.h
+++ b/twin/clients/web/WebButton.h
@@ -41,7 +41,7 @@ namespace Web
Left, Mid, Right
};
- WebButton(ButtonType type, WebClient *parent, const char *name, bool shape);
+ WebButton(ButtonType type, WebClient *parent, const char *name, bool tqshape);
virtual ~WebButton();
@@ -59,7 +59,7 @@ namespace Web
bool mouseOver_;
- bool shape_;
+ bool tqshape_;
WebClient* deco_;
};
}
diff --git a/twin/clients/b2/b2client.cpp b/twin/clients/b2/b2client.cpp
index 6036a7276..c5786146a 100644
--- a/twin/clients/b2/b2client.cpp
+++ b/twin/clients/b2/b2client.cpp
@@ -12,7 +12,7 @@
#include "b2client.h"
#include <tqapplication.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqdrawutil.h>
#include <kpixmapeffect.h>
#include <kimageeffect.h>
@@ -419,7 +419,7 @@ void B2Client::init()
titleLayout->addSpacing(3);
- TQColor c = options()->colorGroup(KDecoration::ColorTitleBar, isActive()).
+ TQColor c = options()->tqcolorGroup(KDecoration::ColorTitleBar, isActive()).
color(TQColorGroup::Button);
for (int i = 0; i < BtnCount; i++) {
@@ -558,7 +558,7 @@ bool B2Client::mustDrawHandle() const
void B2Client::iconChange()
{
if (button[BtnMenu])
- button[BtnMenu]->repaint(false);
+ button[BtnMenu]->tqrepaint(false);
}
// Gallium: New button show/hide magic for customizable
@@ -607,7 +607,7 @@ void B2Client::resizeEvent(TQResizeEvent * /*e*/)
titleMoveAbs(bar_x_ofs);
doShape();
- widget()->repaint(); // the frame is misrendered without this
+ widget()->tqrepaint(); // the frame is misrendered without this
}
void B2Client::captionChange()
@@ -616,7 +616,7 @@ void B2Client::captionChange()
titleMoveAbs(bar_x_ofs);
doShape();
titlebar->recalcBuffer();
- titlebar->repaint(false);
+ titlebar->tqrepaint(false);
}
void B2Client::paintEvent(TQPaintEvent* e)
@@ -635,7 +635,7 @@ void B2Client::paintEvent(TQPaintEvent* e)
int bb = mustDrawHandle() ? 4 : 0;
int bDepth = thickness + bb;
- TQColorGroup fillColor = options()->colorGroup(frameColorGroup, isActive());
+ TQColorGroup fillColor = options()->tqcolorGroup(frameColorGroup, isActive());
TQBrush fillBrush(options()->color(frameColorGroup, isActive()));
// outer frame rect
@@ -710,7 +710,7 @@ void B2Client::paintEvent(TQPaintEvent* e)
visibilitinotify events until its state changes, so we just try
*/
if (titlebar->isFullyObscured()) {
/* We first see, if our repaint contained the titlebar area */
TQRegion reg(TQRect(0, 0, width(), buttonSize + 4));
reg = reg.intersect(e->region());
if (!reg.isEmpty())
@@ -815,8 +815,8 @@ void B2Client::titleMoveAbs(int new_ofs)
bar_x_ofs = new_ofs;
positionButtons();
doShape();
- widget()->repaint(0, 0, width(), buttonSize + 4, false);
- titlebar->repaint(false);
+ widget()->tqrepaint(0, 0, width(), buttonSize + 4, false);
+ titlebar->tqrepaint(false);
}
}
@@ -841,7 +841,7 @@ void B2Client::maximizeChange()
bool m = maximizeMode() == MaximizeFull;
if (button[BtnMax]) {
button[BtnMax]->setPixmaps(m ? P_NORMALIZE : P_MAX);
- button[BtnMax]->repaint();
+ button[BtnMax]->tqrepaint();
TQToolTip::remove(button[BtnMax]);
TQToolTip::add(button[BtnMax],
m ? i18n("Restore") : i18n("Maximize"));
@@ -851,21 +851,21 @@ void B2Client::maximizeChange()
g->activate();
doShape();
- widget()->repaint(false);
+ widget()->tqrepaint(false);
}
void B2Client::activeChange()
{
- widget()->repaint(false);
- titlebar->repaint(false);
+ widget()->tqrepaint(false);
+ titlebar->tqrepaint(false);
- TQColor c = options()->colorGroup(
+ TQColor c = options()->tqcolorGroup(
KDecoration::ColorTitleBar, isActive()).color(TQColorGroup::Button);
for (int i = 0; i < BtnCount; i++)
if (button[i]) {
button[i]->setBg(c);
- button[i]->repaint(false);
+ button[i]->tqrepaint(false);
}
}
@@ -881,7 +881,7 @@ void B2Client::shadeChange()
}
}
-TQSize B2Client::minimumSize() const
+TQSize B2Client::tqminimumSize() const
{
int left, right, top, bottom;
borders(left, right, top, bottom);
@@ -960,8 +960,8 @@ void B2Client::unobscureTitlebar()
static void redraw_pixmaps()
{
int i;
- TQColorGroup aGrp = options()->colorGroup(KDecoration::ColorButtonBg, true);
- TQColorGroup iGrp = options()->colorGroup(KDecoration::ColorButtonBg, false);
+ TQColorGroup aGrp = options()->tqcolorGroup(KDecoration::ColorButtonBg, true);
+ TQColorGroup iGrp = options()->tqcolorGroup(KDecoration::ColorButtonBg, false);
// close
drawB2Rect(PIXMAP_A(P_CLOSE), aGrp.button(), false);
@@ -1128,7 +1128,7 @@ void B2Client::positionButtons()
// Transparent bound stuff.
static TQRect *visible_bound;
-static TQPointArray bound_shape;
+static TQPointArray bound_tqshape;
bool B2Client::drawbound(const TQRect& geom, bool clear)
{
@@ -1153,7 +1153,7 @@ bool B2Client::drawbound(const TQRect& geom, bool clear)
barLeft += 2;
barRight -= 2;
- bound_shape.putPoints(0, 8,
+ bound_tqshape.putPoints(0, 8,
g.left(), frameTop,
barLeft, frameTop,
barLeft, g.top(),
@@ -1168,7 +1168,7 @@ bool B2Client::drawbound(const TQRect& geom, bool clear)
TQPainter p(workspaceWidget());
p.setPen(TQPen(Qt::white, 5));
p.setRasterOp(TQt::XorROP);
- p.drawPolygon(bound_shape);
+ p.drawPolygon(bound_tqshape);
if (clear) {
delete visible_bound;
@@ -1222,7 +1222,7 @@ B2Button::B2Button(B2Client *_client, TQWidget *parent,
}
-TQSize B2Button::sizeHint() const
+TQSize B2Button::tqsizeHint() const
{
return TQSize(buttonSize, buttonSize);
}
@@ -1273,7 +1273,7 @@ void B2Button::setPixmaps(int button_id)
for (int i = 0; i < NumStates; i++) {
icon[i] = B2::pixmap[button_id + i];
}
- repaint(false);
+ tqrepaint(false);
}
void B2Button::mousePressEvent(TQMouseEvent * e)
@@ -1297,14 +1297,14 @@ void B2Button::mouseReleaseEvent(TQMouseEvent * e)
void B2Button::enterEvent(TQEvent *e)
{
hover = true;
- repaint(false);
+ tqrepaint(false);
TQButton::enterEvent(e);
}
void B2Button::leaveEvent(TQEvent *e)
{
hover = false;
- repaint(false);
+ tqrepaint(false);
TQButton::leaveEvent(e);
}
@@ -1363,7 +1363,7 @@ void B2Titlebar::drawTitlebar(TQPainter &p, bool state)
// titlebar fill
const TQColorGroup cg =
- options()->colorGroup(KDecoration::ColorTitleBar, state);
+ options()->tqcolorGroup(KDecoration::ColorTitleBar, state);
TQBrush brush(cg.background());
if (gradient) brush.setPixmap(*gradient);
qDrawShadeRect(&p, 1, 1, t.right() - 1, t.height() - 1,
@@ -1388,7 +1388,7 @@ void B2Titlebar::recalcBuffer()
void B2Titlebar::resizeEvent(TQResizeEvent *)
{
recalcBuffer();
- repaint(false);
+ tqrepaint(false);
}
@@ -710,7 +710,7 @@ void B2Client::paintEvent(TQPaintEvent* e)
*/
if (titlebar->isFullyObscured()) {
- /* We first see, if our repaint contained the titlebar area */
+ /* We first see, if our tqrepaint contained the titlebar area */
TQRegion reg(TQRect(0, 0, width(), buttonSize + 4));
reg = reg.intersect(e->region());
diff --git a/twin/clients/default/kdedefault.cpp b/twin/clients/default/kdedefault.cpp
index a9e9cdbe8..f3b8fa2ba 100644
--- a/twin/clients/default/kdedefault.cpp
+++ b/twin/clients/default/kdedefault.cpp
@@ -18,7 +18,7 @@
#include <kimageeffect.h>
#include <kdrawutil.h>
#include <klocale.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqdrawutil.h>
#include <tqbitmap.h>
#include <tqimage.h>
@@ -240,7 +240,7 @@ unsigned long KDEDefaultHandler::readConfig( bool update )
|| new_useGradients != useGradients
|| new_titleHeight != normalTitleHeight
|| new_toolTitleHeight != toolTitleHeight )
- changed |= SettingColors; // just recreate the pixmaps and repaint
+ changed |= SettingColors; // just recreate the pixmaps and tqrepaint
}
showGrabBar = new_showGrabBar;
@@ -328,7 +328,7 @@ void KDEDefaultHandler::createPixmaps()
TQPainter p;
// Active pins
- g = options()->colorGroup( ColorButtonBg, true );
+ g = options()->tqcolorGroup( ColorButtonBg, true );
pinUpPix = new KPixmap();
pinUpPix->resize(16, 16);
p.begin( pinUpPix );
@@ -346,7 +346,7 @@ void KDEDefaultHandler::createPixmaps()
pinDownPix->setMask( TQBitmap(16, 16, pindown_mask_bits, true) );
// Inactive pins
- g = options()->colorGroup( ColorButtonBg, false );
+ g = options()->tqcolorGroup( ColorButtonBg, false );
ipinUpPix = new KPixmap();
ipinUpPix->resize(16, 16);
p.begin( ipinUpPix );
@@ -404,25 +404,25 @@ void KDEDefaultHandler::createPixmaps()
irightBtnDownPix[false]->resize(toolTitleHeight, toolTitleHeight);
// Draw the button state pixmaps
- g = options()->colorGroup( ColorTitleBar, true );
+ g = options()->tqcolorGroup( ColorTitleBar, true );
drawButtonBackground( leftBtnUpPix[true], g, false );
drawButtonBackground( leftBtnDownPix[true], g, true );
drawButtonBackground( leftBtnUpPix[false], g, false );
drawButtonBackground( leftBtnDownPix[false], g, true );
- g = options()->colorGroup( ColorButtonBg, true );
+ g = options()->tqcolorGroup( ColorButtonBg, true );
drawButtonBackground( rightBtnUpPix[true], g, false );
drawButtonBackground( rightBtnDownPix[true], g, true );
drawButtonBackground( rightBtnUpPix[false], g, false );
drawButtonBackground( rightBtnDownPix[false], g, true );
- g = options()->colorGroup( ColorTitleBar, false );
+ g = options()->tqcolorGroup( ColorTitleBar, false );
drawButtonBackground( ileftBtnUpPix[true], g, false );
drawButtonBackground( ileftBtnDownPix[true], g, true );
drawButtonBackground( ileftBtnUpPix[false], g, false );
drawButtonBackground( ileftBtnDownPix[false], g, true );
- g = options()->colorGroup( ColorButtonBg, false );
+ g = options()->tqcolorGroup( ColorButtonBg, false );
drawButtonBackground( irightBtnUpPix[true], g, false );
drawButtonBackground( irightBtnDownPix[true], g, true );
drawButtonBackground( irightBtnUpPix[false], g, false );
@@ -720,7 +720,7 @@ void KDEDefaultButton::drawButton(TQPainter *p)
void KDEDefaultButton::enterEvent(TQEvent *e)
{
isMouseOver=true;
- repaint(false);
+ tqrepaint(false);
TQButton::enterEvent(e);
}
@@ -728,7 +728,7 @@ void KDEDefaultButton::enterEvent(TQEvent *e)
void KDEDefaultButton::leaveEvent(TQEvent *e)
{
isMouseOver=false;
- repaint(false);
+ tqrepaint(false);
TQButton::leaveEvent(e);
}
@@ -856,7 +856,7 @@ void KDEDefaultClient::init()
void KDEDefaultClient::reset( unsigned long changed)
{
- widget()->repaint();
+ widget()->tqrepaint();
KCommonDecoration::reset(changed);
}
@@ -909,7 +909,7 @@ void KDEDefaultClient::paintEvent( TQPaintEvent* )
p.drawRect(x,y,w,h);
// Draw part of the frame that is the titlebar color
- g = options()->colorGroup(ColorTitleBar, isActive());
+ g = options()->tqcolorGroup(ColorTitleBar, isActive());
p.setPen(g.light());
p.drawLine(x+1, y+1, rightOffset-1, y+1);
p.drawLine(x+1, y+1, x+1, leftFrameStart+borderWidth-4);
@@ -929,7 +929,7 @@ void KDEDefaultClient::paintEvent( TQPaintEvent* )
p.drawLine(x+borderWidth-2, y+titleHeight+3, x+borderWidth-2, leftFrameStart-2);
// Fill out the border edges
- g = options()->colorGroup(ColorFrame, isActive());
+ g = options()->tqcolorGroup(ColorFrame, isActive());
p.setPen(g.light());
p.drawLine(rightOffset, y+1, x2-1, y+1);
p.drawLine(x+1, leftFrameStart+borderWidth-3, x+1, y2-1);
diff --git a/twin/clients/keramik/keramik.cpp b/twin/clients/keramik/keramik.cpp
index 999ab1ee8..e514e3a20 100644
--- a/twin/clients/keramik/keramik.cpp
+++ b/twin/clients/keramik/keramik.cpp
@@ -25,7 +25,7 @@
#include <kiconeffect.h>
#include <tqpainter.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqbitmap.h>
#include <tqstyle.h>
#include <tqtooltip.h>
@@ -784,7 +784,7 @@ void KeramikButton::enterEvent( TQEvent *e )
TQButton::enterEvent( e );
hover = true;
- repaint( false );
+ tqrepaint( false );
}
@@ -793,7 +793,7 @@ void KeramikButton::leaveEvent( TQEvent *e )
TQButton::leaveEvent( e );
hover = false;
- repaint( false );
+ tqrepaint( false );
}
@@ -832,14 +832,14 @@ void KeramikButton::drawButton( TQPainter *p )
if ( isDown() ) {
// Pressed
- p->drawPixmap( TQPoint(), *pix, TQStyle::visualRect( TQRect(2*size, 0, size, size), pix->rect() ) );
+ p->drawPixmap( TQPoint(), *pix, TQStyle::tqvisualRect( TQRect(2*size, 0, size, size), pix->rect() ) );
p->translate( TQApplication::reverseLayout() ? -1 : 1, 1 );
} else if ( hover )
// Mouse over
- p->drawPixmap( TQPoint(), *pix, TQStyle::visualRect( TQRect(size, 0, size, size), pix->rect() ) );
+ p->drawPixmap( TQPoint(), *pix, TQStyle::tqvisualRect( TQRect(size, 0, size, size), pix->rect() ) );
else
// Normal
- p->drawPixmap( TQPoint(), *pix, TQStyle::visualRect( TQRect(0, 0, size, size), pix->rect() ) );
+ p->drawPixmap( TQPoint(), *pix, TQStyle::tqvisualRect( TQRect(0, 0, size, size), pix->rect() ) );
// Draw the button deco on the bevel
@@ -1014,13 +1014,13 @@ void KeramikClient::reset( unsigned long )
captionBufferDirty = maskDirty = true;
// Only repaint the window if it's visible
// (i.e. not minimized and on the current desktop)
if ( widget()->isVisible() ) {
- widget()->repaint( false );
+ widget()->tqrepaint( false );
for ( int i = 0; i < NumButtons; i++ )
- if ( button[i] ) button[i]->repaint( false );
+ if ( button[i] ) button[i]->tqrepaint( false );
}
}
@@ -1280,7 +1280,7 @@ void KeramikClient::updateCaptionBuffer()
( clientHandler->showAppIcons() ? 16 + iconSpacing : 0 );
int xpos = QMAX( (captionRect.width() - tw) / 3, 8 );
- TQRect tr = TQStyle::visualRect( TQRect(xpos, 1, captionRect.width() - xpos - 10,
+ TQRect tr = TQStyle::tqvisualRect( TQRect(xpos, 1, captionRect.width() - xpos - 10,
captionRect.height() - 4), captionBuffer.rect() );
//p.setPen( Qt::red ); // debug
@@ -1289,7 +1289,7 @@ void KeramikClient::updateCaptionBuffer()
// Application icon
if ( clientHandler->showAppIcons() )
{
- TQRect iconRect = TQStyle::visualRect( TQRect(tr.x(),
+ TQRect iconRect = TQStyle::tqvisualRect( TQRect(tr.x(),
1 + (captionRect.height() - 4 - 16) / 2, 16, 16), tr );
TQRect r( icon->rect() );
r.moveCenter( iconRect.center() );
@@ -1349,7 +1349,7 @@ void KeramikClient::calculateCaptionRect()
cw += 16 + 4; // icon width + space
cw = QMIN( cw, titlebar->geometry().width() );
- captionRect = TQStyle::visualRect( TQRect(titlebar->geometry().x(), (largeCaption ? 0 : titleBaseY),
+ captionRect = TQStyle::tqvisualRect( TQRect(titlebar->geometry().x(), (largeCaption ? 0 : titleBaseY),
cw, clientHandler->titleBarHeight(largeCaption) ),
titlebar->geometry() );
}
@@ -1365,7 +1365,7 @@ void KeramikClient::captionChange()
captionBufferDirty = true;
- widget()->repaint( r | captionRect, false );
+ widget()->tqrepaint( r | captionRect, false );
}
@@ -1381,7 +1381,7 @@ void KeramikClient::iconChange()
activeIcon = inactiveIcon = NULL;
captionBufferDirty = true;
- widget()->repaint( captionRect, false );
+ widget()->tqrepaint( captionRect, false );
}
}
@@ -1400,10 +1400,10 @@ void KeramikClient::activeChange()
captionBufferDirty = true;
- widget()->repaint( false );
+ widget()->tqrepaint( false );
for ( int i=0; i < NumButtons; i++ )
- if ( button[i] ) button[i]->repaint( false );
+ if ( button[i] ) button[i]->tqrepaint( false );
}
@@ -1420,7 +1420,7 @@ void KeramikClient::maximizeChange()
captionBufferDirty = maskDirty = true;
widget()->layout()->activate();
- widget()->repaint( false );
+ widget()->tqrepaint( false );
} else if (( maximizeMode() & MaximizeVertical ) == 0 && !largeTitlebar ) {
// We've been restored - enlarge the titlebar by 3 pixels
topSpacer->changeSize( 10, 4, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
@@ -1430,14 +1430,14 @@ void KeramikClient::maximizeChange()
captionBufferDirty = maskDirty = true;
widget()->layout()->activate();
- widget()->repaint( false );
+ widget()->tqrepaint( false );
}
}
if ( button[ MaxButton ] ) {
TQToolTip::remove( button[ MaxButton ] );
TQToolTip::add( button[ MaxButton ], maximizeMode() == MaximizeFull ? i18n("Restore") : i18n("Maximize") );
- button[ MaxButton ]->repaint();
+ button[ MaxButton ]->tqrepaint();
}
}
@@ -1446,7 +1446,7 @@ void KeramikClient::desktopChange()
{
if ( button[ OnAllDesktopsButton ] )
{
- button[ OnAllDesktopsButton ]->repaint( true );
+ button[ OnAllDesktopsButton ]->tqrepaint( true );
TQToolTip::remove( button[ OnAllDesktopsButton ] );
TQToolTip::add( button[ OnAllDesktopsButton ], isOnAllDesktops() ? i18n("Not on all desktops") : i18n("On all desktops") );
}
@@ -1457,7 +1457,7 @@ void KeramikClient::shadeChange()
{
if ( button[ ShadeButton ] )
{
- button[ ShadeButton ]->repaint( true );
+ button[ ShadeButton ]->tqrepaint( true );
TQToolTip::remove( button[ ShadeButton ] );
TQToolTip::add( button[ ShadeButton ], isSetShade() ? i18n("Unshade") : i18n("Shade") );
}
@@ -1467,14 +1467,14 @@ void KeramikClient::shadeChange()
void KeramikClient::keepAboveChange( bool )
{
if ( button[ AboveButton ] )
- button[ AboveButton ]->repaint( true );
+ button[ AboveButton ]->tqrepaint( true );
}
void KeramikClient::keepBelowChange( bool )
{
if ( button[ BelowButton ] )
- button[ BelowButton ]->repaint( true );
+ button[ BelowButton ]->tqrepaint( true );
}
@@ -1502,21 +1502,21 @@ void KeramikClient::slotMaximize()
void KeramikClient::slotAbove()
{
setKeepAbove( !keepAbove());
- button[ AboveButton ]->repaint( true );
+ button[ AboveButton ]->tqrepaint( true );
}
void KeramikClient::slotBelow()
{
setKeepBelow( !keepBelow());
- button[ BelowButton ]->repaint( true );
+ button[ BelowButton ]->tqrepaint( true );
}
void KeramikClient::slotShade()
{
setShade( !isSetShade());
- button[ ShadeButton ]->repaint( true );
+ button[ ShadeButton ]->tqrepaint( true );
}
@@ -1794,9 +1794,9 @@ void KeramikClient::borders( int& left, int& right, int& top, int& bottom ) cons
}
-TQSize KeramikClient::minimumSize() const
+TQSize KeramikClient::tqminimumSize() const
{
- return widget()->minimumSize();
+ return widget()->tqminimumSize();
}
@@ -1014,13 +1014,13 @@ void KeramikClient::reset( unsigned long )
captionBufferDirty = maskDirty = true;
- // Only repaint the window if it's visible
+ // Only tqrepaint the window if it's visible
// (i.e. not minimized and on the current desktop)
if ( widget()->isVisible() ) {
diff --git a/twin/clients/quartz/quartz.cpp b/twin/clients/quartz/quartz.cpp
index 21b4c039c..d0b8974cf 100644
--- a/twin/clients/quartz/quartz.cpp
+++ b/twin/clients/quartz/quartz.cpp
@@ -291,18 +291,18 @@ void QuartzHandler::drawBlocks( KPixmap *pi, KPixmap &p, const TQColor &c1, cons
void QuartzHandler::createPixmaps()
{
// Obtain titlebar blend colours, and create the block stuff on pixmaps.
- TQColorGroup g2 = options()->colorGroup(ColorTitleBlend, true);
+ TQColorGroup g2 = options()->tqcolorGroup(ColorTitleBlend, true);
TQColor c2 = g2.background();
- g2 = options()->colorGroup(ColorTitleBar, true );
+ g2 = options()->tqcolorGroup(ColorTitleBar, true );
TQColor c = g2.background().light(130);
titleBlocks = new KPixmap();
titleBlocks->resize( normalTitleHeight*25/18, normalTitleHeight );
drawBlocks( titleBlocks, *titleBlocks, c, c2 );
- g2 = options()->colorGroup(ColorTitleBlend, false);
+ g2 = options()->tqcolorGroup(ColorTitleBlend, false);
c2 = g2.background();
- g2 = options()->colorGroup(ColorTitleBar, false );
+ g2 = options()->tqcolorGroup(ColorTitleBar, false );
c = g2.background().light(130);
ititleBlocks = new KPixmap();
@@ -313,9 +313,9 @@ void QuartzHandler::createPixmaps()
TQColorGroup g;
TQPainter p;
- g = options()->colorGroup( onAllDesktopsButtonOnLeft ? ColorTitleBar : ColorTitleBlend, true );
+ g = options()->tqcolorGroup( onAllDesktopsButtonOnLeft ? ColorTitleBar : ColorTitleBlend, true );
c = onAllDesktopsButtonOnLeft ? TQColor(g.background().light(130)) : g.background();
- g2 = options()->colorGroup( ColorButtonBg, true );
+ g2 = options()->tqcolorGroup( ColorButtonBg, true );
pinUpPix = new KPixmap();
pinUpPix->resize(16, 16);
@@ -335,9 +335,9 @@ void QuartzHandler::createPixmaps()
// Inactive pins
- g = options()->colorGroup( onAllDesktopsButtonOnLeft ? ColorTitleBar : ColorTitleBlend, false );
+ g = options()->tqcolorGroup( onAllDesktopsButtonOnLeft ? ColorTitleBar : ColorTitleBlend, false );
c = onAllDesktopsButtonOnLeft ? TQColor(g.background().light(130)) : g.background();
- g2 = options()->colorGroup( ColorButtonBg, false );
+ g2 = options()->tqcolorGroup( ColorButtonBg, false );
ipinUpPix = new KPixmap();
ipinUpPix->resize(16, 16);
@@ -437,7 +437,7 @@ void QuartzButton::setBitmap(const unsigned char *bitmap)
if (bitmap) {
deco = new TQBitmap(10, 10, bitmap, true);
deco->setMask( *deco );
- repaint( false );
+ tqrepaint( false );
}
}
@@ -643,8 +643,8 @@ void QuartzClient::reset( unsigned long changed )
{
if (changed & SettingColors || changed & SettingFont)
{
- // repaint the whole thing
- widget()->repaint(false);
+ // tqrepaint the whole thing
+ widget()->tqrepaint(false);
}
KCommonDecoration::reset(changed);
@@ -675,9 +675,9 @@ void QuartzClient::paintEvent( TQPaintEvent* )
// Draw part of the frame that is the title color
if( coloredFrame )
- g = options()->colorGroup(ColorTitleBar, isActive());
+ g = options()->tqcolorGroup(ColorTitleBar, isActive());
else
- g = options()->colorGroup(ColorFrame, isActive());
+ g = options()->tqcolorGroup(ColorFrame, isActive());
// Draw outer highlights and lowlights
p.setPen( g.light().light(120) );
diff --git a/twin/clients/web/Web.cpp b/twin/clients/web/Web.cpp
index f799e1b8b..793b406af 100644
--- a/twin/clients/web/Web.cpp
+++ b/twin/clients/web/Web.cpp
@@ -120,31 +120,31 @@ KCommonDecorationButton *WebClient::createButton(ButtonType type)
{
switch (type) {
case MenuButton:
- return new WebButton(MenuButton, this, "menu", shape_);
+ return new WebButton(MenuButton, this, "menu", tqshape_);
case OnAllDesktopsButton:
- return new WebButton(OnAllDesktopsButton, this, "on_all_desktops", shape_);
+ return new WebButton(OnAllDesktopsButton, this, "on_all_desktops", tqshape_);
case HelpButton:
- return new WebButton(HelpButton, this, "help", shape_);
+ return new WebButton(HelpButton, this, "help", tqshape_);
case MinButton:
- return new WebButton(MinButton, this, "minimize", shape_);
+ return new WebButton(MinButton, this, "minimize", tqshape_);
case MaxButton:
- return new WebButton(MaxButton, this, "maximize", shape_);
+ return new WebButton(MaxButton, this, "maximize", tqshape_);
case CloseButton:
- return new WebButton(CloseButton, this, "close", shape_);
+ return new WebButton(CloseButton, this, "close", tqshape_);
case AboveButton:
- return new WebButton(AboveButton, this, "above", shape_);
+ return new WebButton(AboveButton, this, "above", tqshape_);
case BelowButton:
- return new WebButton(BelowButton, this, "below", shape_);
+ return new WebButton(BelowButton, this, "below", tqshape_);
case ShadeButton:
- return new WebButton(ShadeButton, this, "shade", shape_);
+ return new WebButton(ShadeButton, this, "shade", tqshape_);
default:
return 0;
@@ -185,7 +185,7 @@ WebClient::init()
KConfig c("twinwebrc");
c.setGroup("General");
- shape_ = c.readBoolEntry("Shape", true);
+ tqshape_ = c.readBoolEntry("Shape", true);
KCommonDecoration::init();
}
@@ -195,8 +195,8 @@ WebClient::reset( unsigned long changed )
{
if (changed & SettingColors)
{
- // repaint the whole thing
- widget()->repaint(false);
+ // tqrepaint the whole thing
+ widget()->tqrepaint(false);
} else if (changed & SettingFont) {
// font has changed -- update title height
// title height
@@ -206,7 +206,7 @@ WebClient::reset( unsigned long changed )
if (0 != titleHeight_ % 2)
titleHeight_ += 1;
- widget()->repaint(false);
+ widget()->tqrepaint(false);
}
KCommonDecoration::reset(changed);
@@ -231,7 +231,7 @@ WebClient::paintEvent(TQPaintEvent * pe)
TQPainter p(widget());
p.setPen(Qt::black);
- p.setBrush(options()->colorGroup(ColorFrame, isActive()).background());
+ p.setBrush(options()->tqcolorGroup(ColorFrame, isActive()).background());
p.setClipRegion(pe->region() - titleRect);
@@ -241,7 +241,7 @@ WebClient::paintEvent(TQPaintEvent * pe)
p.fillRect(titleRect, options()->color(ColorTitleBar, isActive()));
- if (shape_)
+ if (tqshape_)
{
int r(width());
int b(height());
@@ -288,7 +288,7 @@ WebClient::paintEvent(TQPaintEvent * pe)
void WebClient::updateWindowShape()
{
- if (!shape_)
+ if (!tqshape_)
return;
TQRegion mask(0, 0, width(), height());